-- ESODR_UniqueIDFromLink by Dan Stone (@khaibit) - dankitymao@gmail.com 
--     & Chris Lasswell (@Philgo68) - Philgo68@gmail.com

-- returns an int YYYYWW
function ESODR_CurrentWeek() 
  local time = GetTimeStamp()
  local epocYears = math.floor(time / 31556926)
  local epocWeeks = math.floor((time - (epocYears * 31556926)) / 604800)
  return (1970 + epocYears) * 100 + epocWeeks
end

-- returns an int YYYYWW
function ESODR_PreviousWeek() 
  local time = GetTimeStamp() - 604800
  local epocYears = math.floor(time / 31556926)
  local epocWeeks = math.floor((time - (epocYears * 31556926)) / 604800)
  return (1970 + epocYears) *100 + epocWeeks
end

-- makeIndexFromLink function from MasterMerchant so our IDs are identical.
-- The index consists of the item's required level, required vet
-- level, quality, and trait(if any), separated by colons.
function ESODR_UniqueIDFromLink(itemLink)
  if itemLink == nil then return end
  local levelReq = GetItemLinkRequiredLevel(itemLink)
  local vetReq = 0
  local champ = GetItemLinkRequiredChampionPoints(itemLink)
  if champ then
    vetReq = champ / 10
  end
  local itemQuality = GetItemLinkQuality(itemLink)  
  local itemTrait = GetItemLinkTraitInfo(itemLink)
  --Add final number in the link to handle item differences like 2 and 3 buff potions
  local theLastNumber = string.match(itemLink, '|H.-:item:.-:(%d-)|h') or 0
  
  local index = levelReq .. ':' .. vetReq .. ':' .. itemQuality .. ':' .. itemTrait .. ':' .. theLastNumber

  return index
end

function ESODR_ItemIDFromLink(itemLink)
  if itemLink == nil then return end
  return itemLink:match("|H.-:.-:(.-):")
end

-- returns a table of guild store items.
function ESODR_GetGuildStoreItemTable(itemID, uniqueID)

  itemID = tonumber(itemID)
  
  if not ESODataRelay.GuildStoreItems then return end
  local data = ESODataRelay.GuildStoreItems

  if not data[itemID] then return end
  if not data[itemID][uniqueID] then return end
  return data[itemID][uniqueID]["items"]
end

-- returns statistics for the given week, could be nil
function ESODR_StatisticsForWeek(itemID, uniqueID, week)
  itemID = tonumber(itemID)
  week = tonumber(week)
  
  if not ESODataRelay.Statistics then return end
  local data = ESODataRelay.Statistics
  if not data[itemID] then return end
  if not data[itemID][uniqueID] then return end
  
  return data[itemID][uniqueID]
end

-- returns statistics for the given range of days, could be nil
-- options are 7, 15, 30
function ESODR_StatisticsForRange(itemID, uniqueID, days)
  itemID = tonumber(itemID)
  week = tonumber(week)
  
  if not ESODataRelay.Statistics then return end
  local data = ESODataRelay.StatisticsDays
  if not data[itemID] then return end
  if not data[itemID][uniqueID] then return end
  if not data[itemID][uniqueID][days] then return end
  
  return data[itemID][uniqueID][days]
end

function ESODR_NumberToText(amount)
  local formatted = string.format('%.0f', amount)
  local k
  while true do  
    formatted, k = string.gsub(formatted, "^(-?%d+)(%d%d%d)", '%1,%2')
    if (k==0) then
      break
    end
  end
  return formatted
end

function ESODR_CurrencyToText(amount)
  local formatted = string.format('%.2f', amount)
  local k
  while true do  
    formatted, k = string.gsub(formatted, "^(-?%d+)(%d%d%d)", '%1,%2')
    if (k==0) then
      break
    end
  end
  return formatted
end
